@@ -825,7 +825,8 @@ R <- diag(J)
 R[1,2] <- R[2,1] <- .25
 R[1,3] <- R[3,1] <- .5
 R[2,4] <- R[4,2] <- .75
-(Sigma <- diag(sqrt(1:J / 2)) %*% R %*% diag(sqrt(1:J / 2)))
+### ATLAS and M1mac print 0 as something < .Machine$double.eps
+round(Sigma <- diag(sqrt(1:J / 2)) %*% R %*% diag(sqrt(1:J / 2)), 7)
 (C <- t(chol(Sigma)))
 
 
@@ -960,66 +961,33 @@ M <-
 c(1000, 1105, 1221, 1349, 1491, 1648, 1822, 2013, 2225, 2459, 
 2718, 3004, 3320, 3669, 4055, 4481, 4953, 5473, 6049, 6685, 7389, 
 8166, 9025, 9974, 11023, 12182)
-lGB <-
-structure(c(0.054000000000002046, -880.49261248615869, 0.054000000000002046, 
--880.49242591762345, 0.054000000000002046, -880.49299587719224, 
-0.053999999999994941, -880.49262902245289, 0.054000000000002046, 
--880.49023141833743, 0.054999999999999716, -880.49278384818467, 
-0.054000000000002046, -880.49263211493064, 0.054999999999999716, 
--880.48929666151639, 0.054000000000002046, -880.49251644257947, 
-0.054000000000002046, -880.49133879555245, 0.054000000000002046, 
--880.49209059546854, 0.10999999999999943, -880.49160057988672, 
-0.11399999999999721, -880.49355264445524, 0.11100000000000421, 
--880.49125049308975, 0.10799999999999699, -880.49215052698423, 
-0.10800000000000409, -880.49227539674052, 0.10900000000000176, 
--880.4918790945195, 0.10900000000000176, -880.49200824376248, 
-0.19200000000000017, -880.49213191772731, 0.19500000000000028, 
--880.49183887878723, 0.19400000000000261, -880.49213912969094, 
-0.19399999999999551, -880.49104161510115, 0.1980000000000004, 
--880.49219786133153, 0.32800000000000296, -880.49160034162105, 
-0.3230000000000004, -880.49194070754265, 0.3230000000000004, 
--880.49169841069408), dim = c(2L, 26L), dimnames = list(c("user.self", 
-"ll"), NULL))
-lH <-
-structure(c(0.022999999999996135, -880.48029630630356, 0.027000000000001023, 
--880.49616556706735, 0.028999999999996362, -880.48868341221828, 
-0.031999999999996476, -880.49617133610923, 0.034999999999996589, 
--880.48559676487218, 0.039000000000001478, -880.49133269164929, 
-0.042999999999999261, -880.49455705455455, 0.047999999999994714, 
--880.49542914386404, 0.052999999999997272, -880.49439060601685, 
-0.059999999999995168, -880.48554604736751, 0.064000000000000057, 
--880.49145473103829, 0.071000000000005059, -880.49413777944255, 
-0.079000000000000625, -880.49161893244116, 0.087000000000003297, 
--880.49339336832497, 0.094999999999998863, -880.49254091532248, 
-0.10599999999999454, -880.49164929759263, 0.117999999999995, 
--880.49250821826354, 0.12900000000000489, -880.49255823649469, 
-0.14100000000000534, -880.49250899551407, 0.15699999999999648, 
--880.49044836032715, 0.17300000000000182, -880.4916864321558, 
-0.19299999999999784, -880.49117821390132, 0.21099999999999852, 
--880.49228594426586, 0.23299999999999699, -880.49151053053481, 
-0.25800000000000267, -880.49153034586084, 0.28699999999999903, 
--880.49192862086477), dim = c(2L, 26L), dimnames = list(c("user.self", 
-"ll"), NULL))
-lHf <-
-structure(c(0.018000000000000682, -880.48706686434321, 0.019000000000005457, 
--880.48863853791863, 0.021999999999998465, -880.48856920618675, 
-0.023999999999993804, -880.49392985529778, 0.026000000000003354, 
--880.48602935577401, 0.029000000000003467, -880.49156265644069, 
-0.033000000000001251, -880.49941537079019, 0.035000000000003695, 
--880.49445708416158, 0.038000000000003809, -880.49395360381868, 
-0.042999999999999261, -880.49364771019248, 0.04700000000000415, 
--880.49295526291712, 0.051999999999999602, -880.4946669985851, 
-0.058999999999997499, -880.49374458475813, 0.064999999999997726, 
--880.49419536692346, 0.070000000000000284, -880.49332997377735, 
-0.07799999999999585, -880.49145097709174, 0.086000000000005627, 
--880.49237859905554, 0.094000000000001194, -880.49039213464482, 
-0.10599999999999454, -880.49106109560728, 0.11500000000000199, 
--880.49157721254892, 0.12899999999999778, -880.49252340367264, 
-0.14199999999999591, -880.49102722425221, 0.15800000000000125, 
--880.49208613066503, 0.17099999999999227, -880.4920686898173, 
-0.18899999999999295, -880.4922510767417, 0.20799999999999841, 
--880.4923471956962), dim = c(2L, 26L), dimnames = list(c("user.self", 
-"ll"), NULL))
+lGB <- matrix(c(0.054, -880.492612, 0.054, -880.492426, 0.054, -880.492996, 0.054,
+-880.492629, 0.054, -880.490231, 0.055, -880.492784, 0.054, -880.492632,
+0.055, -880.489297, 0.054, -880.492516, 0.054, -880.491339, 0.054,
+-880.492091, 0.11, -880.491601, 0.114, -880.493553, 0.111, -880.49125,
+0.108, -880.492151, 0.108, -880.492275, 0.109, -880.491879, 0.109,
+-880.492008, 0.192, -880.492132, 0.195, -880.491839, 0.194, -880.492139,
+0.194, -880.491042, 0.198, -880.492198, 0.328, -880.4916, 0.323,
+-880.491941, 0.323, -880.491698), nrow = 2)
+rownames(lGB) <- c("user.self", "ll")
+lH <- matrix(c(0.023, -880.480296, 0.027, -880.496166, 0.029, -880.488683,
+0.032, -880.496171, 0.035, -880.485597, 0.039, -880.491333, 0.043,
+-880.494557, 0.048, -880.495429, 0.053, -880.494391, 0.06, -880.485546,
+0.064, -880.491455, 0.071, -880.494138, 0.079, -880.491619, 0.087,
+-880.493393, 0.095, -880.492541, 0.106, -880.491649, 0.118, -880.492508,
+0.129, -880.492558, 0.141, -880.492509, 0.157, -880.490448, 0.173,
+-880.491686, 0.193, -880.491178, 0.211, -880.492286, 0.233, -880.491511,
+0.258, -880.49153, 0.287, -880.491929), nrow = 2) 
+rownames(lH) <- c("user.self", "ll")
+lHf <- matrix(c(0.018, -880.487067, 0.019, -880.488639, 0.022, -880.488569,
+0.024, -880.49393, 0.026, -880.486029, 0.029, -880.491563, 0.033,
+-880.499415, 0.035, -880.494457, 0.038, -880.493954, 0.043, -880.493648,
+0.047, -880.492955, 0.052, -880.494667, 0.059, -880.493745, 0.065,
+-880.494195, 0.07, -880.49333, 0.078, -880.491451, 0.086, -880.492379,
+0.094, -880.490392, 0.106, -880.491061, 0.115, -880.491577, 0.129,
+-880.492523, 0.142, -880.491027, 0.158, -880.492086, 0.171, -880.492069,
+0.189, -880.492251, 0.208, -880.492347), nrow = 2) 
+rownames(lHf) <- c("user.self", "ll")
 
 
 ###################################################
@@ -1061,8 +1029,9 @@ ll <- function(parm, J) {
 ###################################################
 prm <- c(mn, unclass(lt))
 ll(prm, J = J)
-lpmvnormR(lwr, upr, mean = mn, chol = lt, 
-         algorithm = GenzBretz(maxpts = M, abseps = 0, releps = 0))
+### ATLAS gives -880.4908, M1mac gives -880.4911
+round(lpmvnormR(lwr, upr, mean = mn, chol = lt, 
+                algorithm = GenzBretz(maxpts = M, abseps = 0, releps = 0)), 3)
 (llprm <- lpmvnorm(lwr, upr, mean = mn, chol = lt, w = W, M = M))
 chk(llprm, sum(lpmvnorm(lwr, upr, mean = mn, chol = lt, w = W, 
                         M = M, logLik = FALSE)))
@@ -1128,9 +1097,10 @@ mn
 ###################################################
 ### code chunk number 61: ex-ML-Shat
 ###################################################
-Tcrossprod(lt)		### true Sigma
-Tcrossprod(C)           ### interval-censored obs
-Shat                    ### "exact" obs
+### ATLAS print issues
+round(Tcrossprod(lt), 7)  ### true Sigma
+round(Tcrossprod(C), 7)   ### interval-censored obs
+round(Shat, 7)            ### "exact" obs
 
 
 ###################################################
@@ -1157,7 +1127,10 @@ H <- optim(op$par, fn = ll, gr = sc, J = J, method = "L-BFGS-B",
 ###################################################
 ### code chunk number 65: ML-sample
 ###################################################
-L <- t(chol(H))
+L <- try(t(chol(H)))
+### some check on r-oldrel-macos-arm64
+if (inherits(L, "try-error"))
+    L <- t(chol(H + 1e-4 * diag(nrow(H))))
 L <- ltMatrices(L[lower.tri(L, diag = TRUE)], diag = TRUE)
 Nsim <- 50000
 Z <- matrix(rnorm(Nsim * nrow(H)), ncol = Nsim)
