@@ -57,8 +57,8 @@
       EXTERNAL TVTMFN, ADONET, BVTL
       INTEGER NU, NUC
       DOUBLE PRECISION H(3), H1, H2, H3, R(3), R12, R13, R23, EPSI
-      DOUBLE PRECISION ONE, ZRO, EPS, ZROS(3), HS(3), TVT, TVTL
-      DOUBLE PRECISION RUA, RUB, AR, RUC, PT, BVTL, PHID, ADONET
+      DOUBLE PRECISION ONE, ZRO, EPS, TVT, TVTL
+      DOUBLE PRECISION RUA, RUB, AR, RUC, PT, BVTL, PHID, ADONET, TVTMFN
       PARAMETER ( ZRO = 0, ONE = 1 )
       COMMON /TVTMBK/ H1, H2, H3, R23, RUA, RUB, AR, RUC, NUC
       EPS = MAX( 1D-14, EPSI )
@@ -367,7 +367,7 @@
       DOUBLE PRECISION GMPH, GMPK, XNKH, XNHK, QHRK, HKN, HPK, HKRN
       DOUBLE PRECISION BTNCKH, BTNCHK, BTPDKH, BTPDHK, ONE, EPS
       PARAMETER ( ONE = 1, EPS = 1D-15 )
-      IF ( NU .LE. 0 ) THEN ! NU == 0  (<==>  nu = Inf  <==> normal distrib
+      IF ( NU .LE. 0 ) THEN ! NU == 0 means normal distr
          BVTL = BVND( -DH, -DK, R )
       ELSE IF ( 1 - R .LE. EPS ) THEN
          BVTL = STUDNT( NU, MIN( DH, DK ) )
