@@ -1,5 +1,7 @@
 library("mvtnorm")
 
+chk <- function(...) isTRUE(all.equal(...))
+
 ## Showing the TVPACK() gives *NON*-random results:
 (cor1 <- toeplitz(c(1, 1/4, -1/8)))
 (up1  <- c(1/4, 7/4, 5/8))
@@ -11,10 +13,10 @@ pmvt.. <- function(df, algorithm)
 dfs <- 1:9
 pmvt_TV.7 <- replicate(7, pmvt..(dfs, TVPACK()))
 
-stopifnot(pmvt_TV.7 == pmvt_TV.7[,1])
+stopifnot(identical(unique(c(pmvt_TV.7 - pmvt_TV.7[,1])), 0))
 (pmvt.TV. <- pmvt_TV.7[,1])
 (pmvt.TV  <- pmvt..(dfs, TVPACK(1e-14)))# has no effect here
-all.equal(max(abs(pmvt.TV - pmvt.TV.)), 0) ## all 0 {unexpectedly ??}
+chk(max(abs(pmvt.TV - pmvt.TV.)), 0) ## all 0 {unexpectedly ??}
 
 
 set.seed(47) ## and default algorithm: -> *random* result
@@ -23,7 +25,7 @@ pmvt_7 <- replicate(7, vapply(dfs, function(df) pmvt(df=df, upper=up1, corr=cor1
 relE <- 1 - pmvt_7 / pmvt.TV
 rng.rE <- range(abs(relE))
 stopifnot(1e-6 < rng.rE[1], rng.rE[2] < 7e-4)
-stopifnot(all.equal(
+stopifnot(chk(
     colMeans(abs(relE)),
     c(88, 64, 105, 73, 52, 90, 87)*1e-6, tol= 1e-3))
 
@@ -116,11 +118,11 @@ P2 <- pmvnorm(lower=c(-Inf, 0, 0), upper=Inf, corr=S, algorithm = Miwa())
 P2a<- pmvnorm(lower=c(-Inf, 0, 0), upper=Inf, corr=S, algorithm = Miwa(512))
 P2.<- pmvnorm(lower=c(-Inf, 0, 0), upper=Inf, corr=S, algorithm = Miwa(2048))
 
-stopifnot(all.equal(1/3, c(P0), tol=1e-14)
-        , all.equal(1/3, c(P1), tol=1e-14)
-        , all.equal(1/3, c(P2), tol=1e-9 ) # 3.765e-10
-        , all.equal(1/3, c(P2a),tol=4e-12) # 8.32 e-13
-        , all.equal(1/3, c(P2.),tol=2e-12) # 5.28 e-13
+stopifnot(chk(1/3, c(P0), tol=1e-14),
+          chk(1/3, c(P1), tol=1e-14),
+          chk(1/3, c(P2), tol=1e-9 ), # 3.765e-10
+          chk(1/3, c(P2a),tol=4e-12), # 8.32 e-13
+          chk(1/3, c(P2.),tol=2e-12) # 5.28 e-13
 )
 
 ## t-dist [TVPACK() had failed] :
@@ -130,6 +132,6 @@ unique(Ptdef)# see length 1; i.e., same result [even though default is Monte-Car
 Pt1 <- pmvt(lower=c(-Inf, 1, 2), upper=Inf, df=2, corr=S, algorithm = TVPACK())
 P. <- 0.0570404044526986
 stopifnot(exprs = {
-    all.equal(P., c(Pt1), tol = 1e-14)# seen 3.65 e-16
+    chk(P., c(Pt1), tol = 1e-14)# seen 3.65 e-16
     abs(P. - Ptdef) < 1e-15 # seen 1.39 e-17
 })
